@@ -454,7 +454,7 @@ int32_t SPVM__Digest__MD5__md5(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_string = stack[0].oval;
         
         if (!obj_string) {
-          return env->die(env, stack, "The input must be defined", FILE_NAME, __LINE__);
+          return env->die(env, stack, "The input must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         data = (unsigned char *)env->get_chars(env, stack, obj_string);
@@ -477,7 +477,7 @@ int32_t SPVM__Digest__MD5__md5_hex(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_string = stack[0].oval;
         
         if (!obj_string) {
-          return env->die(env, stack, "The input must be defined", FILE_NAME, __LINE__);
+          return env->die(env, stack, "The input must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         data = (unsigned char *)env->get_chars(env, stack, obj_string);
@@ -500,7 +500,7 @@ int32_t SPVM__Digest__MD5__md5_base64(SPVM_ENV* env, SPVM_VALUE* stack) {
         void* obj_string = stack[0].oval;
         
         if (!obj_string) {
-          return env->die(env, stack, "The input must be defined", FILE_NAME, __LINE__);
+          return env->die(env, stack, "The input must be defined", __func__, FILE_NAME, __LINE__);
         }
         
         data = (unsigned char *)env->get_chars(env, stack, obj_string);
@@ -519,18 +519,18 @@ int32_t SPVM__Digest__MD5__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e;
   
-  void* obj_self = env->new_object_by_name(env, stack, "Digest::MD5", &e, FILE_NAME, __LINE__);
+  void* obj_self = env->new_object_by_name(env, stack, "Digest::MD5", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   MD5_CTX* ctx = env->alloc_memory_block_zero(env, sizeof(MD5_CTX));
 
   MD5Init(ctx);
   
-  void* obj_ctx = env->new_object_by_name(env, stack, "Digest::MD5::Context", &e, FILE_NAME, __LINE__);
+  void* obj_ctx = env->new_object_by_name(env, stack, "Digest::MD5::Context", &e, __func__, FILE_NAME, __LINE__);
   
   env->set_pointer(env, stack, obj_ctx, ctx);
   
-  env->set_field_object_by_name(env, stack, obj_self, "context", obj_ctx, &e, FILE_NAME, __LINE__);
+  env->set_field_object_by_name(env, stack, obj_self, "context", obj_ctx, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_self;
@@ -546,13 +546,13 @@ int32_t SPVM__Digest__MD5__add(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_string = stack[1].oval;
   
   if (!obj_string) {
-    return env->die(env, stack, "The input must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The input must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   const char* data = (unsigned char *)env->get_chars(env, stack, obj_string);
   int32_t len = env->length(env, stack, obj_string);
   
-  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, FILE_NAME, __LINE__);
+  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   MD5_CTX* ctx = env->get_pointer(env, stack, obj_ctx);
@@ -568,7 +568,7 @@ int32_t SPVM__Digest__MD5__digest(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e;
   void* obj_self = stack[0].oval;
   
-  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, FILE_NAME, __LINE__);
+  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, __func__, FILE_NAME, __LINE__);
   
   if (e) { return e; }
   
@@ -585,7 +585,7 @@ int32_t SPVM__Digest__MD5__hexdigest(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e;
   void* obj_self = stack[0].oval;
   
-  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, FILE_NAME, __LINE__);
+  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   MD5_CTX* ctx = env->get_pointer(env, stack, obj_ctx);
@@ -601,7 +601,7 @@ int32_t SPVM__Digest__MD5__b64digest(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e;
   void* obj_self = stack[0].oval;
   
-  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, FILE_NAME, __LINE__);
+  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   MD5_CTX* ctx = env->get_pointer(env, stack, obj_ctx);
@@ -619,7 +619,7 @@ int32_t SPVM__Digest__MD5__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
-  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, FILE_NAME, __LINE__);
+  void* obj_ctx = env->get_field_object_by_name(env, stack, obj_self, "context", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   MD5_CTX* ctx = env->get_pointer(env, stack, obj_ctx);
